@@ -1,7 +1,7 @@
 package TableDef;
 
-our $VERSION = '1.0.4'; # VERSION
-our $DATE = '2014-06-29'; # DATE
+our $VERSION = '1.0.5'; # VERSION
+our $DATE = '2014-09-20'; # DATE
 
 1;
 # ABSTRACT: Table data definition
@@ -18,7 +18,7 @@ TableDef - Table data definition
 
 =head1 VERSION
 
-This document describes version 1.0.4 of TableDef (from Perl distribution TableDef), released on 2014-06-29.
+This document describes version 1.0.5 of TableDef (from Perl distribution TableDef), released on 2014-09-20.
 
 =head1 HOMEPAGE
 
@@ -38,11 +38,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
